"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.AccordionPanel = exports.AccordionItem = exports.AccordionButton = void 0;
var _react = _interopRequireWildcard(require("react"));
var _box = _interopRequireDefault(require("../../atoms/box/box"));
var _collapse = _interopRequireDefault(require("../../atoms/collapse/collapse"));
var _pearl = require("../../../pearl");
var _pressable = _interopRequireDefault(require("../../atoms/pressable/pressable"));
var _icon = _interopRequireDefault(require("../../atoms/icon/icon"));
var _stack = _interopRequireDefault(require("../../atoms/stack/stack"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
/**
 * Props for AccordionItem component.
 */

/**
 * Props for AccordionButton component.
 */

/**
 * Props for AccordionPanel component.
 */

const AccordionContext = /*#__PURE__*/_react.default.createContext({
  expansionStatus: [],
  reduceMotion: false,
  itemProps: {},
  buttonProps: {},
  panelProps: {}
});
const AccordionItemContext = /*#__PURE__*/_react.default.createContext({
  index: 0
});
const BaseAccordion = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(({
  atoms,
  children,
  ...rest
}, ref) => {
  const {
    allowMultiple = false,
    allowToggle = false,
    defaultIndices = [],
    reduceMotion = false,
    ...otherContainerProps
  } = atoms.container;
  const [expansionStatus, setExpansionStatus] = (0, _react.useState)(new Array(_react.default.Children.count(children)).fill(false).map((_, index) => defaultIndices.includes(index)));
  const toggleExpanded = index => {
    setExpansionStatus(prevIsExpanded => {
      const newIsExpanded = [...prevIsExpanded];
      if (allowToggle && !allowMultiple) {
        newIsExpanded[index] = !newIsExpanded[index];
      } else if (!allowToggle && allowMultiple) {
        newIsExpanded[index] = true;
      } else if (allowToggle && allowMultiple) {
        newIsExpanded[index] = !newIsExpanded[index];
      } else {
        newIsExpanded.fill(false);
        newIsExpanded[index] = true;
      }
      return newIsExpanded;
    });
  };
  return /*#__PURE__*/_react.default.createElement(AccordionContext.Provider, {
    value: {
      reduceMotion,
      expansionStatus,
      itemProps: atoms.item,
      buttonProps: {
        ...atoms.button,
        onPress: idx => toggleExpanded(idx)
      },
      panelProps: atoms.panel
    }
  }, /*#__PURE__*/_react.default.createElement(_stack.default, _extends({}, rest, {
    ref: ref
  }, otherContainerProps), _react.default.Children.map(children, (child, index) => /*#__PURE__*/_react.default.cloneElement(child, {
    key: index,
    index: index
  }))));
}));
const AccordionItem = exports.AccordionItem = /*#__PURE__*/_react.default.memo(({
  children,
  key,
  index = 0,
  ...props
}) => {
  const {
    itemProps,
    expansionStatus
  } = _react.default.useContext(AccordionContext);
  const isExpanded = !!expansionStatus[index];
  return /*#__PURE__*/_react.default.createElement(_stack.default, _extends({
    w: "100%"
  }, itemProps, props), /*#__PURE__*/_react.default.createElement(AccordionItemContext.Provider, {
    value: {
      index: index
    }
  }, typeof children === "function" ? children(isExpanded) : children));
});
const AccordionButton = exports.AccordionButton = /*#__PURE__*/_react.default.memo(({
  children,
  icon,
  ...props
}) => {
  const {
    buttonProps,
    expansionStatus
  } = _react.default.useContext(AccordionContext);
  const {
    index
  } = _react.default.useContext(AccordionItemContext);
  const isExpanded = !!expansionStatus[index];
  if (!icon) icon = /*#__PURE__*/_react.default.createElement(_icon.default, {
    size: "xs",
    iconFamily: "Feather",
    iconName: isExpanded ? "chevron-up" : "chevron-down"
  });
  return /*#__PURE__*/_react.default.createElement(_pressable.default, _extends({}, buttonProps, props, {
    accessible: true,
    accessibilityRole: "button",
    onPress: () => {
      if (buttonProps.onPress) buttonProps.onPress(index);
    }
  }), /*#__PURE__*/_react.default.createElement(_box.default, {
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center"
  }, children, icon && /*#__PURE__*/_react.default.cloneElement(icon)));
});
const AccordionPanel = exports.AccordionPanel = /*#__PURE__*/_react.default.memo(({
  children,
  ...props
}) => {
  const {
    panelProps,
    reduceMotion,
    expansionStatus
  } = _react.default.useContext(AccordionContext);
  const {
    index
  } = _react.default.useContext(AccordionItemContext);
  const isExpanded = !!expansionStatus[index];
  return /*#__PURE__*/_react.default.createElement(_collapse.default, _extends({}, panelProps, props, {
    show: isExpanded,
    transition: reduceMotion ? {
      type: "timing",
      duration: 1
    } : undefined,
    exitTransition: reduceMotion ? {
      type: "timing",
      duration: 1
    } : undefined
  }), children);
});

/** The Accordion component provides an expandable view. */
const Accordion = (0, _pearl.pearl)(BaseAccordion, {
  componentName: "Accordion",
  type: "molecule",
  animatable: true
}, undefined, {
  partForOverridenAnimationProps: "container",
  partForOverridenNativeProps: "container",
  partForOverridenStyleProps: "container"
});
Accordion.displayName = "Accordion";
AccordionItem.displayName = "AccordionItem";
AccordionButton.displayName = "AccordionButton";
AccordionPanel.displayName = "AccordionPanel";
var _default = exports.default = Accordion;
//# sourceMappingURL=accordion.js.map