"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDynamicStateStyle = void 0;
var _lodash = _interopRequireDefault(require("lodash"));
var _styleFunctions = require("../../theme/src/style-functions");
var _utils = require("../../theme/utils/utils");
var _useStateWithStyleProps = require("../useStateWithStyleProps");
var _utils2 = require("../utils/utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * Hook to manage a pressed state and compose extra styling while a component is pressed
 *
 * @param props - The props of the component
 * @param stateKey - The key of the state to manage
 * @param currentState - The current state of the component
 * @param styleFunctions - The style functions to use
 * @param activeComponentType - The active component type
 * @param animateable - Whether the component is animateable
 * @returns The final props of the component
 */
const useDynamicStateStyle = (props, stateKey, currentState, styleFunctions = _styleFunctions.boxStyleFunctions, activeComponentType = "basic", animateable = true) => {
  // Override the pressed state if the parentStateValue is provided
  let stateStyles = (0, _useStateWithStyleProps.useStateWithStyleProps)(props[stateKey], styleFunctions);
  delete props[stateKey];

  // If there are no state styles, return the original props
  if (!stateStyles) return props;
  const animateableStyles = _lodash.default.omit(stateStyles, _utils2.NON_ANIMATEABLE_STYLE_PROPS);
  const allStylePropertyKeys = _styleFunctions.allStyleFunctions.map(val => val.property);
  const animateableStyleProperties = Object.values(_lodash.default.omit(allStylePropertyKeys, _utils2.NON_ANIMATEABLE_STYLE_PROPS));
  let finalProps = props;

  // If the component is animateable, add missing required styles from the 'from' prop to the base style
  if (animateable) {
    // If the current state is true, add the state styles to the animate prop
    if (currentState) {
      finalProps.animate = {
        ...finalProps.animate,
        ...(0, _utils.removeUndefined)(animateableStyles)
      };
    }
    if (!finalProps.animate) finalProps.animate = undefined;
  } else {
    // If the component is not animateable and the current state is true, add the state styles to the style prop
    if (currentState) {
      if (activeComponentType !== "molecule") {
        finalProps.style = {
          ...finalProps.style,
          ...(0, _utils.removeUndefined)(stateStyles)
        };
      } else {
        finalProps = {
          ...finalProps,
          ...(0, _utils.removeUndefined)(stateStyles)
        };
      }
    }
  }
  return finalProps;
};
exports.useDynamicStateStyle = useDynamicStateStyle;
//# sourceMappingURL=useDynamicStateStyle.js.map