"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useHoveredState = void 0;
var _react = require("react");
var _styleFunctions = require("../../theme/src/style-functions");
var _useDynamicStateStyle = require("./useDynamicStateStyle");
/**
 * Hook to manage a hovered state and compose extra styling while a component is hovered
 * @param props The props object of a component
 * @param styleFunctions List of style functions supported by the component. By default, boxStyleFunctions are used
 * @param activeComponentType Type of the component inside which the hook is used. By default, this value is set to 'basic'
 * @param animateable Whether the styles should be dynamically animated using Moti. By default, this value is set to 'true'
 * @param parentStateValue A override value to control the 'hovered' state instead of the local state value
 * @returns The props object with updated styles according the current 'hovered' state
 */
const useHoveredState = (props, styleFunctions = _styleFunctions.boxStyleFunctions, activeComponentType = "basic", animateable = true, parentStateValue = undefined) => {
  // Initialize hovered state to false
  const [hovered, setHovered] = (0, _react.useState)(false);

  // Override the hovered state if the parentStateValue is provided
  let finalHoveredFlag;
  if (parentStateValue !== undefined) {
    finalHoveredFlag = parentStateValue;
  } else {
    finalHoveredFlag = hovered;
  }

  // Compose extra styling while a component is hovered
  const propsWithHoveredStyles = (0, _useDynamicStateStyle.useDynamicStateStyle)(props, "_hovered", finalHoveredFlag, styleFunctions, activeComponentType, animateable);
  return {
    hovered,
    setHovered,
    propsWithHoveredStyles
  };
};
exports.useHoveredState = useHoveredState;
//# sourceMappingURL=useHoveredState.js.map