function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import Stack, { HStack } from "../stack/stack";
import Icon from "../icon/icon";
import Text from "../text/text";
/**
 * List is a layout component that arranges its children into a list.
 * Each child is given an equal amount of space.
 * An optional icon can be displayed next to each child.
 */
const List = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(({
  children,
  renderIcon = undefined,
  ...props
}, ref) => {
  return /*#__PURE__*/React.createElement(Stack, _extends({
    ref: ref
  }, props), React.Children.map(children, (child, index) => /*#__PURE__*/React.createElement(HStack, {
    key: index,
    spacing: "2.5"
  }, renderIcon && renderIcon(index), child)));
}));

/**
 * OrderedList is a layout component that arranges its children into an ordered list.
 */
export const OrderedList = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(({
  children,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement(List, _extends({}, rest, {
    renderIcon: () => /*#__PURE__*/React.createElement(Icon, {
      iconFamily: "FontAwesome",
      iconName: "circle",
      rawSize: 6,
      mt: "2"
    }),
    ref: ref
  }), children);
}));

/**
 * UnorderedList is a layout component that arranges its children into an unordered list.
 */
export const UnorderedList = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(({
  children,
  ...rest
}, ref) => {
  return /*#__PURE__*/React.createElement(List, _extends({}, rest, {
    renderIcon: index => /*#__PURE__*/React.createElement(Text, {
      variant: "p4"
    }, index + 1, "."),
    ref: ref
  }), children);
}));
List.displayName = "List";
OrderedList.displayName = "OrderedList";
UnorderedList.displayName = "UnorderedList";
export default List;
//# sourceMappingURL=list.js.map