function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from "react";
import Box from "../../atoms/box/box";
import Collapse from "../../atoms/collapse/collapse";
import { pearl } from "../../../pearl";
import Pressable from "../../atoms/pressable/pressable";
import Icon from "../../atoms/icon/icon";
import Stack from "../../atoms/stack/stack";

/**
 * Props for AccordionItem component.
 */

/**
 * Props for AccordionButton component.
 */

/**
 * Props for AccordionPanel component.
 */

const AccordionContext = /*#__PURE__*/React.createContext({
  expansionStatus: [],
  reduceMotion: false,
  itemProps: {},
  buttonProps: {},
  panelProps: {}
});
const AccordionItemContext = /*#__PURE__*/React.createContext({
  index: 0
});
const BaseAccordion = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(({
  atoms,
  children,
  ...rest
}, ref) => {
  const {
    allowMultiple = false,
    allowToggle = false,
    defaultIndices = [],
    reduceMotion = false,
    ...otherContainerProps
  } = atoms.container;
  const [expansionStatus, setExpansionStatus] = useState(new Array(React.Children.count(children)).fill(false).map((_, index) => defaultIndices.includes(index)));
  const toggleExpanded = index => {
    setExpansionStatus(prevIsExpanded => {
      const newIsExpanded = [...prevIsExpanded];
      if (allowToggle && !allowMultiple) {
        newIsExpanded[index] = !newIsExpanded[index];
      } else if (!allowToggle && allowMultiple) {
        newIsExpanded[index] = true;
      } else if (allowToggle && allowMultiple) {
        newIsExpanded[index] = !newIsExpanded[index];
      } else {
        newIsExpanded.fill(false);
        newIsExpanded[index] = true;
      }
      return newIsExpanded;
    });
  };
  return /*#__PURE__*/React.createElement(AccordionContext.Provider, {
    value: {
      reduceMotion,
      expansionStatus,
      itemProps: atoms.item,
      buttonProps: {
        ...atoms.button,
        onPress: idx => toggleExpanded(idx)
      },
      panelProps: atoms.panel
    }
  }, /*#__PURE__*/React.createElement(Stack, _extends({}, rest, {
    ref: ref
  }, otherContainerProps), React.Children.map(children, (child, index) => /*#__PURE__*/React.cloneElement(child, {
    key: index,
    index: index
  }))));
}));
export const AccordionItem = /*#__PURE__*/React.memo(({
  children,
  key,
  index = 0,
  ...props
}) => {
  const {
    itemProps,
    expansionStatus
  } = React.useContext(AccordionContext);
  const isExpanded = !!expansionStatus[index];
  return /*#__PURE__*/React.createElement(Stack, _extends({
    w: "100%"
  }, itemProps, props), /*#__PURE__*/React.createElement(AccordionItemContext.Provider, {
    value: {
      index: index
    }
  }, typeof children === "function" ? children(isExpanded) : children));
});
export const AccordionButton = /*#__PURE__*/React.memo(({
  children,
  icon,
  ...props
}) => {
  const {
    buttonProps,
    expansionStatus
  } = React.useContext(AccordionContext);
  const {
    index
  } = React.useContext(AccordionItemContext);
  const isExpanded = !!expansionStatus[index];
  if (!icon) icon = /*#__PURE__*/React.createElement(Icon, {
    size: "xs",
    iconFamily: "Feather",
    iconName: isExpanded ? "chevron-up" : "chevron-down"
  });
  return /*#__PURE__*/React.createElement(Pressable, _extends({}, buttonProps, props, {
    accessible: true,
    accessibilityRole: "button",
    onPress: () => {
      if (buttonProps.onPress) buttonProps.onPress(index);
    }
  }), /*#__PURE__*/React.createElement(Box, {
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center"
  }, children, icon && /*#__PURE__*/React.cloneElement(icon)));
});
export const AccordionPanel = /*#__PURE__*/React.memo(({
  children,
  ...props
}) => {
  const {
    panelProps,
    reduceMotion,
    expansionStatus
  } = React.useContext(AccordionContext);
  const {
    index
  } = React.useContext(AccordionItemContext);
  const isExpanded = !!expansionStatus[index];
  return /*#__PURE__*/React.createElement(Collapse, _extends({}, panelProps, props, {
    show: isExpanded,
    transition: reduceMotion ? {
      type: "timing",
      duration: 1
    } : undefined,
    exitTransition: reduceMotion ? {
      type: "timing",
      duration: 1
    } : undefined
  }), children);
});

/** The Accordion component provides an expandable view. */
const Accordion = pearl(BaseAccordion, {
  componentName: "Accordion",
  type: "molecule",
  animatable: true
}, undefined, {
  partForOverridenAnimationProps: "container",
  partForOverridenNativeProps: "container",
  partForOverridenStyleProps: "container"
});
Accordion.displayName = "Accordion";
AccordionItem.displayName = "AccordionItem";
AccordionButton.displayName = "AccordionButton";
AccordionPanel.displayName = "AccordionPanel";
export default Accordion;
//# sourceMappingURL=accordion.js.map