function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import { pearl } from "../../../pearl";
import Text from "../../atoms/text/text";
import Icon from "../../atoms/icon/icon";
import Stack from "../../atoms/stack/stack";
import { useStyleProps } from "../../../hooks";
import { boxStyleFunctions } from "../../../theme";
import Box from "../../atoms/box/box";
import IconButton from "../icon-button/icon-button";
import _ from "lodash";

/**
 * BaseAlertProps are the properties for the BaseAlert component.
 * It extends StackProps and adds additional properties.
 */

const BaseAlert = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(({
  atoms,
  children,
  ...rest
}, ref) => {
  let {
    icon,
    withIcon = true,
    title,
    description,
    withCloseButton = false,
    onClose = () => {},
    ...otherContainerProps
  } = atoms.container;
  const computedDescriptionStyles = useStyleProps(atoms.description, boxStyleFunctions);
  if (!icon && withIcon) icon = /*#__PURE__*/React.createElement(Icon, atoms.icon);
  return /*#__PURE__*/React.createElement(Stack, _extends({}, rest, {
    ref: ref
  }, otherContainerProps, {
    accessible: true,
    accessibilityRole: "alert"
  }), icon && /*#__PURE__*/React.cloneElement(icon, {
    ...atoms.icon,
    ...icon.props
  }), /*#__PURE__*/React.createElement(Stack, atoms.stack, /*#__PURE__*/React.createElement(Box, {
    flexDirection: "row",
    justifyContent: "space-between"
  }, title && /*#__PURE__*/React.createElement(Text, atoms.title, title)), description && /*#__PURE__*/React.createElement(Box, {
    style: computedDescriptionStyles.style
  }, /*#__PURE__*/React.createElement(Text, _.omit(computedDescriptionStyles, ["style"]), description))), withCloseButton && /*#__PURE__*/React.createElement(IconButton, _extends({
    position: "absolute",
    top: 5,
    right: 7,
    icon: /*#__PURE__*/React.createElement(Icon, {
      iconFamily: "Ionicons",
      iconName: "close"
    })
  }, atoms.closeButton, {
    onPress: onClose,
    accessible: true,
    accessibilityRole: "button",
    accessibilityLabel: "Close Alert"
  })));
}));

/** Alert is used to display a short, important message in a way that attracts the user's attention without interrupting the user's task. */
const Alert = pearl(BaseAlert, {
  componentName: "Alert",
  type: "molecule",
  animatable: true
}, undefined, {
  partForOverridenAnimationProps: "container",
  partForOverridenNativeProps: "container",
  partForOverridenStyleProps: "container"
});
Alert.displayName = "Alert";
export default Alert;
//# sourceMappingURL=alert.js.map